==> apache-cxf-3.6.8-src.zip: apache-cxf-3.6.8-src/rt/rs/security/jose-parent/jose-jaxrs/src/main/java/org/apache/cxf/rs/security/jose/jaxrs/multipart/AbstractJwsMultipartVerificationFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.rs.security.jose.jaxrs.multipart;

import javax.ws.rs.core.MediaType;

import org.apache.cxf.jaxrs.ext.multipart.MultipartInputFilter;
import org.apache.cxf.jaxrs.utils.JAXRSUtils;
import org.apache.cxf.jaxrs.utils.multipart.AttachmentUtils;
import org.apache.cxf.message.Message;
import org.apache.cxf.rs.security.jose.jws.JwsSignatureVerifier;

public abstract class AbstractJwsMultipartVerificationFilter {
    
    private JwsSignatureVerifier sigVerifier;
    private boolean useJwsJsonSignatureFormat;
    private boolean bufferPayload;
    public void setSigVerifier(JwsSignatureVerifier sigVerifier) {
        this.sigVerifier = sigVerifier;
    }
    
    protected void addMultipartFilterIfNeeded(MediaType contentType) {
        if (contentType != null && "multipart".equals(contentType.getType())) {
            Message m = JAXRSUtils.getCurrentMessage();
            MultipartInputFilter jwsFilter = new JwsMultipartSignatureInFilter(m, 
                                                    sigVerifier, 
                                                    bufferPayload, 
                                                    useJwsJsonSignatureFormat); 
            AttachmentUtils.addMultipartInFilter(jwsFilter); 
        }
        
    }
    
    public void setUseJwsJsonSignatureFormat(boolean useJwsJsonSignatureFormat) {
        this.useJwsJsonSignatureFormat = useJwsJsonSignatureFormat;
    }

    public void setBufferPayload(boolean bufferPayload) {
        this.bufferPayload = bufferPayload;
    }
}

==> apache-cxf-4.1.4-src.zip: apache-cxf-4.1.4-src/rt/rs/security/jose-parent/jose-jaxrs/src/main/java/org/apache/cxf/rs/security/jose/jaxrs/multipart/AbstractJwsMultipartVerificationFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.rs.security.jose.jaxrs.multipart;

import jakarta.ws.rs.core.MediaType;
import org.apache.cxf.jaxrs.ext.multipart.MultipartInputFilter;
import org.apache.cxf.jaxrs.utils.JAXRSUtils;
import org.apache.cxf.jaxrs.utils.multipart.AttachmentUtils;
import org.apache.cxf.message.Message;
import org.apache.cxf.rs.security.jose.jws.JwsSignatureVerifier;

public abstract class AbstractJwsMultipartVerificationFilter {
    
    private JwsSignatureVerifier sigVerifier;
    private boolean useJwsJsonSignatureFormat;
    private boolean bufferPayload;
    public void setSigVerifier(JwsSignatureVerifier sigVerifier) {
        this.sigVerifier = sigVerifier;
    }
    
    protected void addMultipartFilterIfNeeded(MediaType contentType) {
        if (contentType != null && "multipart".equals(contentType.getType())) {
            Message m = JAXRSUtils.getCurrentMessage();
            MultipartInputFilter jwsFilter = new JwsMultipartSignatureInFilter(m, 
                                                    sigVerifier, 
                                                    bufferPayload, 
                                                    useJwsJsonSignatureFormat); 
            AttachmentUtils.addMultipartInFilter(jwsFilter); 
        }
        
    }
    
    public void setUseJwsJsonSignatureFormat(boolean useJwsJsonSignatureFormat) {
        this.useJwsJsonSignatureFormat = useJwsJsonSignatureFormat;
    }

    public void setBufferPayload(boolean bufferPayload) {
        this.bufferPayload = bufferPayload;
    }
}
